pub fn extend_current_method_context() -> MethodHandleExpand description
Produces a handle to the current method context.
The method is active as long as the handle is alive.
pub fn extend_current_method_context() -> MethodHandleProduces a handle to the current method context.
The method is active as long as the handle is alive.