pub fn in_callback_executor_context_for<R>(
method_handle: MethodHandle,
f: impl FnOnce() -> R,
) -> RExpand description
Execute an inter-canister call callback in the context of the method that made it.
pub fn in_callback_executor_context_for<R>(
method_handle: MethodHandle,
f: impl FnOnce() -> R,
) -> RExecute an inter-canister call callback in the context of the method that made it.