pub fn in_tracking_executor_context<R>(f: impl FnOnce() -> R) -> RExpand description
Execute an update function in a context that allows calling spawn_protected and spawn_migratory.
pub fn in_tracking_executor_context<R>(f: impl FnOnce() -> R) -> RExecute an update function in a context that allows calling spawn_protected and spawn_migratory.