pub fn in_tracking_query_executor_context<R>(f: impl FnOnce() -> R) -> RExpand description
Execute a query function in a context that allows calling spawn_protected but not spawn_migratory.
pub fn in_tracking_query_executor_context<R>(f: impl FnOnce() -> R) -> RExecute a query function in a context that allows calling spawn_protected but not spawn_migratory.