spawn_migratory

Function spawn_migratory 

pub fn spawn_migratory(f: impl Future<Output = ()> + 'static) -> TaskHandle
Spawns a task that can migrate between methods.

When the task is awoken, it will run in the context of the method that woke it.