pub struct MethodHandle { /* private fields */ }Expand description
A handle to a method context. If the function returns and all handles have been dropped, the method is considered returned.
This should be created before performing an inter-canister call via extend_current_method_context,
threaded through the env parameter, and then used when calling in_callback_executor_context_for or
in_trap_recovery_context_for. Failure to track this properly may result in unexpected cancellation of tasks.