An async executor for ic-cdk. Most users should not use this crate directly.
Statics
- CLEANUP
- In a cleanup callback, this is set to
truebefore callingwake, andfalseafterwards. This ensures thatwakewill not actually run the future, but instead cancel it and run its destructor.
Functions
- spawn
- Must be called on every top-level future corresponding to a method call of a
canister by the IC, other than async functions marked
#[update]or similar.