pub fn spawn_migratory(f: impl Future<Output = ()> + 'static) -> TaskHandleExpand description
Spawns a task that can migrate between methods.
When the task is awoken, it will run in the context of the method that woke it.
pub fn spawn_migratory(f: impl Future<Output = ()> + 'static) -> TaskHandleSpawns a task that can migrate between methods.
When the task is awoken, it will run in the context of the method that woke it.